package org.dromara.ems.record.service;

import org.dromara.ems.record.domain.EmsRecordSteamInstant;

import java.util.List;

/**
 * 蒸汽实时数据Service接口
 *
 * @author Yinq
 * @date 2024-05-22
 */
public interface IEmsRecordSteamInstantService {
    /**
     * 查询蒸汽实时数据
     *
     * @param objId 蒸汽实时数据主键
     * @return 蒸汽实时数据
     */
    public EmsRecordSteamInstant selectEmsRecordSteamInstantByObjId(Long objId);

    /**
     * 查询蒸汽实时数据列表
     *
     * @param emsRecordSteamInstant 蒸汽实时数据
     * @return 蒸汽实时数据集合
     */
    public List<EmsRecordSteamInstant> selectEmsRecordSteamInstantList(EmsRecordSteamInstant emsRecordSteamInstant);

    /**
     * 新增蒸汽实时数据
     *
     * @param emsRecordSteamInstant 蒸汽实时数据
     * @return 结果
     */
    public int insertEmsRecordSteamInstant(EmsRecordSteamInstant emsRecordSteamInstant);

    /**
     * 修改蒸汽实时数据
     *
     * @param emsRecordSteamInstant 蒸汽实时数据
     * @return 结果
     */
    public int updateEmsRecordSteamInstant(EmsRecordSteamInstant emsRecordSteamInstant);

    /**
     * 批量删除蒸汽实时数据
     *
     * @param objIds 需要删除的蒸汽实时数据主键集合
     * @return 结果
     */
    public int deleteEmsRecordSteamInstantByObjIds(Long[] objIds);

    /**
     * 删除蒸汽实时数据信息
     *
     * @param objId 蒸汽实时数据主键
     * @return 结果
     */
    public int deleteEmsRecordSteamInstantByObjId(Long objId);
}
